@@ -2,6 +2,5 @@
 ;;; For more information see (info "(emacs) Directory Variables")
 
 ((nil . ((indent-tabs-mode . t)
-	 (fill-column . 70)))
- (python-mode . ((indent-tabs-mode . nil)
-		 (fill-column . 78))))
+	 (fill-column . 78)))
+ (python-mode . ((indent-tabs-mode . nil))))
